==> spip_3.0.18.orig.tar.xz: spip/plugins-dist/mediabox/lang/mediabox_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mediabox?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_reinitialiser' => 'Reinitialisà',
	'boxstr_close' => 'Fermà',
	'boxstr_current' => '@current@/@total@',
	'boxstr_next' => 'Seguent',
	'boxstr_previous' => 'Prechedent',
	'boxstr_slideshowStart' => 'Presentacioun',
	'boxstr_slideshowStop' => 'Arrestà',
	'boxstr_zoom' => 'Zoom',

	// E
	'explication_selecteur' => 'Endicàs la bressai dei elemen que desgancheran la bouòta. (Espressioun CSS o destenduda jQuery)',
	'explication_selecteur_galerie' => 'Endicàs la bressai dei elemen da groupà en galerìa. (Espressioun CSS o destenduda jQuery)',
	'explication_splash_url' => 'Endicàs l’url dóu media a afichà automaticamen en una bouòta per la premièra visita sus lou sit public.',
	'explication_traiter_toutes_images' => 'Inserì una bouòta soubre touti li image ?',

	// L
	'label_active' => 'Ativà la bouòta Multimedia soubre lou sit public',
	'label_apparence' => 'Aparença',
	'label_aucun_style' => 'Inserì mìnga ablhage en mancança',
	'label_choix_transition_elastic' => 'Elàstica',
	'label_choix_transition_fade' => 'Founduda encadenada',
	'label_choix_transition_none' => 'Sensa efet de transicioun',
	'label_maxheight' => 'Autessa Massimala (% o px)',
	'label_maxwidth' => 'Larguessa Massimala  (% o px)',
	'label_minheight' => 'Autessa Minimala (% o px)',
	'label_minwidth' => 'Larguessa Minimala (% o px)',
	'label_opacite' => 'Oupachità dóu fount',
	'label_selecteur_commun' => 'En general',
	'label_selecteur_galerie' => 'En galerìa',
	'label_skin' => 'Abilhage visual',
	'label_slideshow_speed' => 'Tems d’espousicioun dei fotò de la presentacioun (ms)',
	'label_speed' => 'Vitessa de transicioun (ms)',
	'label_splash' => 'Splash Bouòta',
	'label_splash_url' => 'URL a afichà',
	'label_traiter_toutes_images' => 'Image',
	'label_transition' => 'Transicioun tra doui afichage',

	// T
	'titre_menu_box' => 'Bouòta Multimedia',
	'titre_page_configurer_box' => 'Counfiguracioun de la Bouòta multimedia'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/mediabox/lang/mediabox_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mediabox?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_reinitialiser' => 'Reinitialisà',
	'boxstr_close' => 'Fermà',
	'boxstr_current' => '@current@/@total@',
	'boxstr_next' => 'Seguent',
	'boxstr_previous' => 'Prechedent',
	'boxstr_slideshowStart' => 'Presentacioun',
	'boxstr_slideshowStop' => 'Arrestà',
	'boxstr_zoom' => 'Zoom',

	// E
	'explication_selecteur' => 'Endicàs la bressai dei elemen que desgancheran la bouòta. (Espressioun CSS o destenduda jQuery)',
	'explication_selecteur_galerie' => 'Endicàs la bressai dei elemen da groupà en galerìa. (Espressioun CSS o destenduda jQuery)',
	'explication_splash_url' => 'Endicàs l’url dóu media da afichà automaticamen en una bouòta per la premièra visita sus lou sit pùblicou.',
	'explication_traiter_toutes_images' => 'Inserì una bouòta soubre touti li image ?',

	// L
	'label_active' => 'Ativà la bouòta Multimedia soubre lou sit pùblicou',
	'label_apparence' => 'Aparença',
	'label_aucun_style' => 'Inserì mìnga ablhage en mancança',
	'label_choix_transition_elastic' => 'Elàstica',
	'label_choix_transition_fade' => 'Foundut encadenat',
	'label_choix_transition_none' => 'Sensa efet de transicioun',
	'label_maxheight' => 'Autessa Massimala (% o px)',
	'label_maxwidth' => 'Larguessa Massimala  (% o px)',
	'label_minheight' => 'Autessa Minimala (% o px)',
	'label_minwidth' => 'Larguessa Minimala (% o px)',
	'label_opacite' => 'Oupachità dóu fount',
	'label_selecteur_commun' => 'En general',
	'label_selecteur_galerie' => 'En galerìa',
	'label_skin' => 'Abilhage visual',
	'label_slideshow_speed' => 'Tems d’espousicioun dei fotò de la presentacioun (ms)',
	'label_speed' => 'Vitessa de transicioun (ms)',
	'label_splash' => 'Splash Bouòta',
	'label_splash_height' => 'Autessa (% o px)',
	'label_splash_url' => 'URL da afichà',
	'label_splash_width' => 'Larguessa (% o px)',
	'label_traiter_toutes_images' => 'Image',
	'label_transition' => 'Transicioun tra doui afichage',

	// T
	'titre_menu_box' => 'Bouòta Multimedia',
	'titre_page_configurer_box' => 'Counfiguracioun de la Bouòta multimedia'
);

?>
